@@ -1,6 +1,6 @@
 package JIRA::REST;
 {
-  $JIRA::REST::VERSION = '0.009';
+  $JIRA::REST::VERSION = '0.010';
 }
 # ABSTRACT: Thin wrapper around JIRA's REST API
 
@@ -115,8 +115,10 @@ sub _error {
         }
     } elsif ($type =~ m:text/html:i && eval {require HTML::TreeBuilder}) {
         $msg .= HTML::TreeBuilder->new_from_content($content)->as_text;
+    } elsif ($type =~ m:^text/:i) {
+        $msg .= "<Content-Type: $type>$content</Content-Type>";
     } else {
-        $msg .= "<unconvertable Content-Type: '$type}'>";
+        $msg .= "<Content-Type: $type>(binary content not shown)</Content-Type>";
     };
     $msg =~ s/\n*$/\n/s;       # end message with a single newline
     return $msg;
@@ -245,6 +247,30 @@ sub next_issue {
     return $iter->{results}{issues}[$iter->{offset}++ - $iter->{results}{startAt}];
 }
 
+sub attach_files {
+    my ($self, $issueIdOrKey, @files) = @_;
+
+    # We need to violate the REST::Client class encapsulation to implement
+    # the HTTP POST method necessary to invoke the /issue/key/attachments
+    # REST endpoint because it has to use the form-data Content-Type.
+
+    my $rest = $self->{rest};
+
+    # FIXME: How to attach all files at once?
+    foreach my $file (@files) {
+        my $response = $rest->getUseragent()->post(
+            $rest->getHost . "/issue/$issueIdOrKey/attachments",
+            %{$rest->{_headers}},
+            'X-Atlassian-Token' => 'nocheck',
+            'Content-Type'      => 'form-data',
+            'Content'           => [ file => [$file] ],
+        );
+
+        $response->is_success
+            or croak $self->_error("attach_files($file): " . $response->status_line);
+    }
+}
+
 1;
 
 __END__
@@ -259,7 +285,7 @@ JIRA::REST - Thin wrapper around JIRA's REST API
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
@@ -303,6 +329,9 @@ version 0.009
         print "Found issue $issue->{key}\n";
     }
 
+    # Attach files using an utility method
+    $jira->attach_files('TST-123', '/path/to/doc.txt', 'image.png');
+
 =head1 DESCRIPTION
 
 L<JIRA|http://www.atlassian.com/software/jira/> is a proprietary bug
@@ -492,6 +521,13 @@ through large sets of issues without worrying about the startAt/total/offset
 attributes in the response from the /search REST endpoint. These methods
 implement the "paging" algorithm needed to work with those attributes.
 
+=head2 B<attach_files> ISSUE FILE...
+
+The C</issue/KEY/attachments> REST endpoint, used to attach files to issues,
+requires a specific content type encoding which is difficult to come up with
+just the C<REST::Client> interface. This utility method offers an easier
+interface to attach files to issues.
+
 =head1 SEE ALSO
 
 =over
